@@ -79,7 +79,7 @@ class Exceptions:
 
 class ElasticTranscoderClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html)
     """
 
@@ -88,13 +88,13 @@ class ElasticTranscoderClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#can_paginate)
         """
 
-    def cancel_job(self, Id: str) -> Dict[str, Any]:
+    def cancel_job(self, *, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.cancel_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#cancel_job)
         """
 
@@ -111,7 +111,7 @@ class ElasticTranscoderClient:
         UserMetadata: Dict[str, str] = None
     ) -> CreateJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_job)
         """
 
@@ -128,7 +128,7 @@ class ElasticTranscoderClient:
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None
     ) -> CreatePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_pipeline)
         """
 
@@ -143,19 +143,19 @@ class ElasticTranscoderClient:
         Thumbnails: "ThumbnailsTypeDef" = None
     ) -> CreatePresetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.create_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#create_preset)
         """
 
-    def delete_pipeline(self, Id: str) -> Dict[str, Any]:
+    def delete_pipeline(self, *, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_pipeline)
         """
 
-    def delete_preset(self, Id: str) -> Dict[str, Any]:
+    def delete_preset(self, *, Id: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.delete_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#delete_preset)
         """
 
@@ -167,7 +167,7 @@ class ElasticTranscoderClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#generate_presigned_url)
         """
 
@@ -175,7 +175,7 @@ class ElasticTranscoderClient:
         self, *, PipelineId: str, Ascending: str = None, PageToken: str = None
     ) -> ListJobsByPipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_pipeline)
         """
 
@@ -183,41 +183,41 @@ class ElasticTranscoderClient:
         self, *, Status: str, Ascending: str = None, PageToken: str = None
     ) -> ListJobsByStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_jobs_by_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_jobs_by_status)
         """
 
     def list_pipelines(
-        self, Ascending: str = None, PageToken: str = None
+        self, *, Ascending: str = None, PageToken: str = None
     ) -> ListPipelinesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_pipelines)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_pipelines)
         """
 
     def list_presets(
-        self, Ascending: str = None, PageToken: str = None
+        self, *, Ascending: str = None, PageToken: str = None
     ) -> ListPresetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.list_presets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#list_presets)
         """
 
-    def read_job(self, Id: str) -> ReadJobResponseTypeDef:
+    def read_job(self, *, Id: str) -> ReadJobResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_job)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_job)
         """
 
-    def read_pipeline(self, Id: str) -> ReadPipelineResponseTypeDef:
+    def read_pipeline(self, *, Id: str) -> ReadPipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_pipeline)
         """
 
-    def read_preset(self, Id: str) -> ReadPresetResponseTypeDef:
+    def read_preset(self, *, Id: str) -> ReadPresetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.read_preset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#read_preset)
         """
 
@@ -225,7 +225,7 @@ class ElasticTranscoderClient:
         self, *, Role: str, InputBucket: str, OutputBucket: str, Topics: List[str]
     ) -> TestRoleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.test_role)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#test_role)
         """
 
@@ -242,21 +242,23 @@ class ElasticTranscoderClient:
         ThumbnailConfig: "PipelineOutputConfigTypeDef" = None
     ) -> UpdatePipelineResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline)
         """
 
     def update_pipeline_notifications(
-        self, Id: str, Notifications: "NotificationsTypeDef"
+        self, *, Id: str, Notifications: "NotificationsTypeDef"
     ) -> UpdatePipelineNotificationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_notifications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_notifications)
         """
 
-    def update_pipeline_status(self, Id: str, Status: str) -> UpdatePipelineStatusResponseTypeDef:
+    def update_pipeline_status(
+        self, *, Id: str, Status: str
+    ) -> UpdatePipelineStatusResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Client.update_pipeline_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/client.html#update_pipeline_status)
         """
 
@@ -265,7 +267,7 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_pipeline"]
     ) -> ListJobsByPipelinePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByPipeline)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbypipelinepaginator)
         """
 
     @overload
@@ -273,22 +275,22 @@ class ElasticTranscoderClient:
         self, operation_name: Literal["list_jobs_by_status"]
     ) -> ListJobsByStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListJobsByStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listjobsbystatuspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_pipelines"]) -> ListPipelinesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPipelines)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpipelinespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_presets"]) -> ListPresetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Paginator.ListPresets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/paginators.html#listpresetspaginator)
         """
 
     def get_waiter(self, waiter_name: Literal["job_complete"]) -> JobCompleteWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.job_complete)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/elastictranscoder.html#ElasticTranscoder.Waiter.job_complete)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elastictranscoder/waiters.html#jobcompletewaiter)
         """
